/*
 * Copyright 2020 ETSI
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holder nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package fr.mines_stetienne.ci.saref.checkers;

import org.apache.jena.rdf.model.Model;
import org.apache.jena.rdf.model.ResIterator;
import org.apache.jena.rdf.model.Resource;
import org.apache.jena.vocabulary.OWL2;
import org.apache.jena.vocabulary.RDF;

import fr.mines_stetienne.ci.saref.SAREFPipelineException;
import fr.mines_stetienne.ci.saref.managers.RepositoryManager;

/**
 * Checks TS 103 673 Clause 9.4.3: The ontology declaration
 * 
 */
public class Clause_9_4_3_Checker extends AbstractClauseChecker {

	private static enum MESSAGE {
		ontology_declaration
	}

	public Clause_9_4_3_Checker(RepositoryManager repositoryManager) {
		super(repositoryManager, Clause_9_4_3_Checker.class);
	}

	@Override
	public void checkClause() throws SAREFPipelineException {
		Model model = version.getModel();
		int onto = 0;
		boolean found = false;
		for (ResIterator it = model.listSubjectsWithProperty(RDF.type, OWL2.Ontology); it.hasNext();) {
			Resource r = it.next();
			if(r.getURI().equals( repository.getNamespace() )) {
				found = true;
			}
			onto++;
		}
		if (onto != 1 || found == false) {
			String msg = getMessage(MESSAGE.ontology_declaration, repository.getNamespace());
			logError(msg);
			return;
		}
//		config.add(version.getRepository().getProject().getResource(), EX.hasVersion, version.getVersionResource());
//		config.add(version.getVersionResource(), RDF.type, EX.OntologyVersion);
//		config.add(version.getVersionResource(), EX.repositoryName, version.getRepository().getProject().getName());
//		config.add(version.getVersionResource(), EX.versionInfo, version.getVersionName().toString());
//		SAREFVersionName priorVersionName = getPriorVersion(version);
//		if (priorVersionName != null) {
//			Resource priorVersionResource = ResourceFactory.createResource(version.getRepository().getVersionIRI(priorVersionName));
//			config.add(version.getVersionResource(), EX.priorVersion, priorVersionResource);
//		}

		new Clause_9_4_3_1_Checker(repositoryManager).check();
		new Clause_9_4_3_2_Checker(repositoryManager).check();
		new Clause_9_4_3_3_Checker(repositoryManager).check();
	}

}
